Traits for implementing IO handlers. This is to enable generic IO. The defaults are the obvious Rust native functions.
Re-exports
pub use client::Client;
Modules
Macros
- display
- Convenience macro for formatting arguments to
Io::print - display_
line - Convenience macro for formatting arguments to
Io::printlnandIo::writeln - edisplay_
line - Convenience macro for formatting arguments to
Io::eprintln - prompt
- A convenience macro for formatting the user prompt before
forwarding it to the
Io::promptmethod.
Structs
- DevNull
Progress Bar - NOOP progress bar implementation.
- NullIo
- Ignores all I/O operations.
- StdIo
- Rust native I/O handling.
Traits
- Io
- A trait that abstracts out I/O operations
- Maybe
Send - Maybe
Sync - Namada
Io - Progress
Bar - Mechanism that allows keeping track of the progress of some operation.
Functions
- prompt_
aux - A generic function for displaying a prompt to users and reading in their response.
- read_
aux - A generic function for reading input from users